//
//  MyCustomChartDelegate.m
//  UsingCustomLabelDelegate
//
//  Created by Darrell Kress on 4/2/14.
//  Copyright (c) 2014 Darrell Kress. All rights reserved.
//

#import "MyCustomChartDelegate.h"
#import <IGChart/IGChart.h>
#import "MyDataClass.h"
@implementation MyCustomChartDelegate
-(NSString *)chartView:(IGChartView *)chartView labelForAxis:(IGAxis *)axis withItem:(NSObject *)item
{
    // We need to filter out that we are looking at the Y-axis.  I know in this case that my Y axis has
    // a key value of "y".
    if([axis.key isEqualToString:@"y"])
    {
        NSNumber* num = ((NSNumber*) item);
        NSNumberFormatter* formatter = [[NSNumberFormatter alloc]init];
        NSString* longString = [formatter stringFromNumber:num];
    
        // I want to make any number > 1000 into a "k" denomination, so if the string is 4 or more characters then clip it, add a k and return.
        
        if (longString.length > 3)
        {
            NSString* subString =  [longString substringToIndex:(longString.length-3)];
            subString = [NSString stringWithFormat:@"%@%@",subString,@"K"];
            return subString;
        }
        
        return longString;
    }
    
    // Since we are overridding this method we also need to handle the X - axis labels.  Since
    // IGLineSeries is a CategorySeries and the x - axis is the category axis in this case, we can
    // cast the item to a IGDataPoint and return the label.
    //IGDataPoint* pt = (IGDataPoint*)item;
    //return pt.label;
    
    // But just doing that isn't any fun.  So instead lets get the underlying data object and make a better label.
    
    IGDataPoint* pt = (IGDataPoint*)item;
    
    IGColumnSeries* colSeries = (IGColumnSeries*)chartView.series[0];
    
    MyDataClass* dataObj = (MyDataClass*)[colSeries.dataSource objectForDataPoint:pt inSeries:colSeries];
    
    NSString* firstInitial = [dataObj.firstName substringToIndex:1];
    
    return [NSString stringWithFormat:@"%@. %@", firstInitial, dataObj.lastName];
}
@end
